#[derive(Protocol, Debug, Clone, PartialEq)]
pub struct RandomMap {
    pub random_maps_ptr: i32,
}
